@@ -8,7 +8,7 @@
  *
  * This is a standard Squirrelmail-1.2 API for plugins.
  *
- * $Id: setup.php 12440 2007-06-07 05:13:51Z jangliss $
+ * $Id: setup.php 13271 2008-09-09 05:54:27Z pdontthink $
  * @package plugins
  * @subpackage sent_subfolders
  */
@@ -319,7 +319,17 @@ function sent_subfolder_getQuarter($month) {
  * @return boolean 1 - is part of sent_subfolders, 0 - is not part of sent_subfolders
  */
 function sent_subfolders_special_mailbox($mb) {
-    global $data_dir, $username, $delimiter;
+    global $data_dir, $username;
+
+    sqgetGlobalVar('delimiter', $delimiter, SQ_SESSION);
+/*
+    if( $imap_server_type == 'uw' ) {
+        $cnd_delimiter = '';
+    } else {
+        $cnd_delimiter = $delimiter;
+    }
+*/        
+    $cnd_delimiter = $delimiter;
 
     $use_sent_subfolders = getPref
         ($data_dir, $username, 'use_sent_subfolders', SMPREF_OFF);
@@ -331,4 +341,3 @@ function sent_subfolders_special_mailbox($mb) {
     }
     return 0;
 }
-?>
\ No newline at end of file
